@@ -4,7 +4,7 @@ import shutil
 import requests
 from pathlib import Path
 
-from .trace import MANAGE, REQUIREMENTS, WSGI, URLS, SETTINGS, VIEWS, MODELS, APP_URLS, ADMIN, README
+from .trace import MANAGE, REQUIREMENTS, WSGI, URLS, SETTINGS, VIEWS, MODELS, ADMIN, README
 
 
 def generate(terminal_token, project_token, *args):
@@ -31,8 +31,8 @@ def generate(terminal_token, project_token, *args):
             'requirements.txt': REQUIREMENTS(),
             'db.sqlite3': '',
             'static/': [],
-            'templates/': [],
-            'templates/admin/': [('base_site.html', """{% extends "admin/base_site.html" %}{% load static %}{% block extrahead %}<link rel="stylesheet" href="https://api.clix.dev/static/admin.css" type="text/css" />{% endblock %}""")],
+            # 'templates/': [], removed at beta
+            # 'templates/admin/': [('base_site.html', """{% extends "admin/base_site.html" %}{% load static %}{% block extrahead %}<link rel="stylesheet" href="https://api.clix.dev/static/admin.css" type="text/css" />{% endblock %}""")],
             project_name + '/': [('__init__.py', ''), ('wsgi.py', WSGI(project_name)), ('settings.py', SETTINGS(project_name, res.get('apps'), res.get('settings'), secret_key)), ('urls.py', URLS(res.get('apps')))],
         }
 
@@ -49,8 +49,9 @@ def generate(terminal_token, project_token, *args):
         
         # generate apps
         for app in res.get('apps'):
+            # removed ('urls.py', APP_URLS(app)) because of beta
             file_extensions = {
-                '': [('__init__.py', ''), ('models.py', MODELS(app)), ('admin.py', ADMIN(app)), ('apps.py', f"from django.apps import AppConfig\n\n\nclass AppConfig(AppConfig):\n\tname = '{app.get('name')}'"), ('tests.py', 'from django.test import TestCase'), ('urls.py', APP_URLS(app)), ('views.py', VIEWS(app))],
+                '': [('__init__.py', ''), ('models.py', MODELS(app)), ('admin.py', ADMIN(app)), ('apps.py', f"from django.apps import AppConfig\n\n\nclass AppConfig(AppConfig):\n\tname = '{app.get('name')}'"), ('tests.py', 'from django.test import TestCase'), ('views.py', VIEWS(app))],
                 'migrations/': [('__init__.py', '')],
             }
             for k, v in file_extensions.items():
